# Formatting Dates with YYYY-MM

    /* data stolen from http://howmanyleft.co.uk/vehicle/jaguar_'e'_type */
    var month_data = [
      {"period": "2012-10", "licensed": 3407, "sorned": 660},
      {"period": "2011-08", "licensed": 3351, "sorned": 629},
      {"period": "2011-03", "licensed": 3269, "sorned": 618},
      {"period": "2010-08", "licensed": 3246, "sorned": 661},
      {"period": "2010-05", "licensed": 3257, "sorned": 667},
      {"period": "2010-03", "licensed": 3248, "sorned": 627},
      {"period": "2010-01", "licensed": 3171, "sorned": 660},
      {"period": "2009-12", "licensed": 3171, "sorned": 676},
      {"period": "2009-10", "licensed": 3201, "sorned": 656},
      {"period": "2009-09", "licensed": 3215, "sorned": 622}
    ];
    Morris.Line({
      element: 'graph',
      data: month_data,
      xkey: 'period',
      ykeys: ['licensed', 'sorned'],
      labels: ['Licensed', 'SORN'],
      smooth: false
    });